@@ -2,6 +2,7 @@
    Copyright 1996, 1997 Linux International.
 
    Contributed by Richard Henderson <rth@tamu.edu>
+   obj_free() added by Bjrn Ekwall <bj0rn@blox.se> March 1999
 
    This file is part of the Linux modutils.
 
@@ -23,7 +24,7 @@
 #ifndef MODUTILS_OBJ_H
 #define MODUTILS_OBJ_H 1
 
-#ident "$Id: obj.h,v 1.1 1997/09/10 22:13:04 rth Exp $"
+#ident "$Id: obj.h 1.1 Tue, 24 Aug 1999 23:26:49 -0700 keith $"
 
 /* The relocatable object is manipulated using elfin types.  */
 
@@ -41,7 +42,7 @@
 # endif
 #endif
 
-/* For some reason this is missing from lib5.  */
+/* For some reason this is missing from libc5.  */
 #ifndef ELF32_ST_INFO
 # define ELF32_ST_INFO(bind, type)       (((bind) << 4) + ((type) & 0xf))
 #endif
@@ -91,6 +92,8 @@ struct obj_file
   struct obj_symbol_patch *symbol_patches;
   int (*symbol_cmp)(const char *, const char *);
   unsigned long (*symbol_hash)(const char *);
+  unsigned long local_symtab_size;
+  struct obj_symbol **local_symtab;
   struct obj_symbol *symtab[HASH_BUCKETS];
 };
 
@@ -126,7 +129,7 @@ unsigned long obj_elf_hash(const char *);
 unsigned long obj_elf_hash_n(const char *, unsigned long len);
 
 struct obj_symbol *obj_add_symbol (struct obj_file *f, const char *name,
-				   int info, int secidx,
+				   unsigned long symidx, int info, int secidx,
 				   ElfW(Addr) value, unsigned long size);
 
 struct obj_symbol *obj_find_symbol (struct obj_file *f,
@@ -163,7 +166,9 @@ int obj_string_patch(struct obj_file *f, int secidx, ElfW(Addr) offset,
 int obj_symbol_patch(struct obj_file *f, int secidx, ElfW(Addr) offset,
 		     struct obj_symbol *sym);
 
-int obj_allocate_commons_and_check_undefineds(struct obj_file *f);
+int obj_check_undefineds(struct obj_file *f, int quiet);
+
+void obj_allocate_commons(struct obj_file *f);
 
 unsigned long obj_load_size (struct obj_file *f);
 
@@ -171,6 +176,8 @@ int obj_relocate (struct obj_file *f, ElfW(Addr) base);
 
 struct obj_file *obj_load(FILE *f);
 
+void obj_free(struct obj_file *f);
+
 int obj_create_image (struct obj_file *f, char *image);
 
 /* Architecture specific manipulation routines.  */
@@ -189,7 +196,9 @@ enum obj_reloc arch_apply_relocation (struct obj_file *f,
 
 int arch_create_got (struct obj_file *f);
 
-struct new_module;
-int arch_init_module (struct obj_file *f, struct new_module *);
+struct module;
+int arch_init_module (struct obj_file *f, struct module *);
+
+int arch_load_proc_section(struct obj_section *sec, FILE *fp);
 
 #endif /* obj.h */
