@@ -931,8 +931,12 @@ static int init_module(const char *m_name, struct obj_file *f, unsigned long m_s
 	obj_create_image(f, image);
 
 	ret = sys_init_module(m_name, (struct module *) image);
-	if (ret)
+	if (ret) {
 		error("init_module: %m");
+		if (ret == -EBUSY)
+			lprintf("Hint: this error can be caused by incorrect module parameters, "
+				"including invalid IO and IRQ parameters\n");
+	}
 
 	free(image);
 
