@@ -5,6 +5,7 @@
  * extended by Bjrn Ekwall <bj0rn@blox.se> in 1994 (C).
  * New re-implementation by Bjrn Ekwall <bj0rn@blox.se> February 1999,
  * Generic kernel module info based on work by Richard Henderson <rth@tamu.edu>
+ * Add ksymoops support by Keith Owens <kaos@ocs.com.au> August 1999,
  *
  * This file is part of the Linux modutils.
  *
@@ -23,8 +24,9 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ident "$Id: rmmod.c 1.1 Tue, 24 Aug 1999 23:26:49 -0700 keith $"
+#ident "$Id: rmmod.c 1.2 Wed, 25 Aug 1999 00:22:12 -0700 keith $"
 
+#include <errno.h>
 #include <unistd.h>
 
 #include "module.h"
@@ -47,17 +49,36 @@ int main(int argc, char **argv)
 	int j;
 	int ret = 0;
 	int recursive = 0;
+	size_t number;
+	size_t bufsize;
+	char *module_names;
 
 	error_file = "rmmod";
 
+	/*
+	 * Collect the loaded modules before deletion.  delete_module()
+	 * gives no indication that any modules were deleted so we have to
+	 * do it the hard way.
+	 */
+	module_names = xmalloc(bufsize = 256);
+	while (query_module(NULL, QM_MODULES, module_names, bufsize, &number)) {
+		if (errno != ENOSPC) {
+			error("QM_MODULES: %m\n");
+			return 0;
+		}
+		module_names = xrealloc(module_names, bufsize = number);
+	}
+
 	while ((i = getopt(argc, argv, "arsV")) != EOF)
 		switch (i) {
 		case 'a':
 			/* Remove all unused modules and stacks.  */
 			if (delete_module(NULL)) {
 				perror("rmmod");
+				snap_shot(module_names, number);
 				return 1;
 			}
+			snap_shot(module_names, number);
 			return 0;
 
 		case 'r':
@@ -90,6 +111,7 @@ int main(int argc, char **argv)
 				perror(argv[1]);
 			}
 		}
+		snap_shot(module_names, number);
 		return ret ? 1 : 0;
 	}
 
@@ -153,5 +175,6 @@ int main(int argc, char **argv)
 		}
 	}
 
+	snap_shot(module_names, number);
 	return ret;
 }
